@@ -24,14 +24,14 @@ package org.apache.maven.shared.model.fileset.mappers;
  * target file name.
  *
  * <p>This is the default FileNameMapper for the archiving tasks and
- * uptodate.</p>
+ * up-to-date.</p>
  *
- * @version $Id: MergingMapper.java 661727 2008-05-30 14:21:49Z bentmann $
+ * @version $Id: MergingMapper.java 1721672 2015-12-25 13:18:36Z khmarbaise $
  */
 public class MergingMapper
     implements FileNameMapper
 {
-    protected String mergedFile = null;
+    private String mergedFile = null;
 
     /** {@inheritDoc} */
     public void setFrom( String from )
